openssl:
let
  # This is the version of OpenSSL that we want to see.
  expected = "1.1.1k";
in {
  # Check the packaging version.  It's nice for this to be what we expect
  # because otherwise things get confusing but this is just the number *we*
  # (or nixpkgs) puts on the software.
  test_package_version = {
    inherit expected;
    expr = openssl.version;
  };

  # Now check that the version OpenSSL itself reports is the same.
  test_runtime_version_matches =
  { inherit expected;
    expr =
      let
        # Find out what openssl thinks its own version is.
        pkgs = import <nixpkgs> { };
        cmd = "${openssl}/bin/openssl version";
        drv = pkgs.runCommand "version" {} "${cmd} > $out";
        runtime_version = builtins.readFile drv;
        pieces = pkgs.lib.splitString " " runtime_version;
      in
        # The pieces are like [ "OpenSSL" "1.1.1k" "25" "Mar" "2021" ].  We
        # don't really care about the date.  Get just the version number.
        builtins.elemAt pieces 1;
  };
}
